@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+import os
 from pathlib import Path
-from typing import List, NamedTuple, Optional, Tuple
+from typing import List, NamedTuple, Optional, Tuple, Union
 
 import mecab_ko_dic
 
@@ -51,21 +52,45 @@ class Feature(NamedTuple):
 
         return cls(**feature)
 
+    def __str__(self) -> str:
+        feature = {
+            key: value if value is not None else "*"
+            for key, value in self._asdict().items()
+        }
+        # True -> T / False -> F / * -> *
+        feature["has_jongseong"] = str(feature["has_jongseong"])[0]
+        return ",".join(feature.values())
+
 
 class MeCabError(Exception):
     pass
 
 
 class MeCab:  # APIs are inspired by KoNLPy
-    def __init__(self, dictionary_directory: Optional[str] = None):
-        if dictionary_directory is None:
-            dictionary_directory = str(mecab_ko_dic.dictionary_path)
+    def __init__(
+        self,
+        dictionary_path: Optional[os.PathLike] = None,
+        user_dictionay_path: Optional[Union[os.PathLike, List[os.PathLike]]] = None,
+    ):
+        if dictionary_path is None:
+            dictionary_path = str(mecab_ko_dic.dictionary_path)
+
+        user_dictionay_argument = []
+        if user_dictionay_path is not None:
+            if not isinstance(user_dictionay_path, list):
+                user_dictionay_path = [user_dictionay_path]
+
+            user_dictionay_argument = [
+                "--userdic",
+                ",".join(f'"{path}"' for path in user_dictionay_path),
+            ]
 
         arguments = [
             "--rcfile",
             str(mecabrc_path),
             "--dicdir",
-            dictionary_directory,
+            dictionary_path,
+            *user_dictionay_argument,
         ]
         self._tagger = _mecab.Tagger(arguments)
 
