@@ -1,7 +1,7 @@
 #include "utils.h"
 
 std::vector<char *> to_argv(const std::vector<std::string> &arguments) {
-  std::vector<char *> argv{""}; // argv[0] is excutable name
+  std::vector<char *> argv{const_cast<char *>("")}; // argv[0] is excutable name
   for (const auto &argument : arguments) {
     argv.push_back(const_cast<char *>(argument.c_str()));
   }
